@@ -35,3 +35,15 @@ test_that("is.404", {
     })
   })
 })
+
+test_that("is.404() deals with local file references", {
+  localMRAN <- system.file("tests/localMRAN", package = "checkpoint")
+  msg <- "Ensure you use the correct http://,  https:// or file:/// prefix."
+  describe("is.404 works on local files", {
+    it("works on local files", {
+      expect_error(is.404(localMRAN), msg)
+      expect_false(is.404(paste0("file:///", localMRAN)))
+      
+    })
+  })
+})
\ No newline at end of file
